@@ -1,7 +1,7 @@
 from __future__ import absolute_import
 from taloncb.quotations import register_xpath_extensions
 try:
-    from talon import signature
+    from taloncb import signature
     ML_ENABLED = True
 except ImportError:
     ML_ENABLED = False
