@@ -26,12 +26,13 @@ import os
 from . import extraction
 from . extraction import extract  #noqa
 from . learning import classifier
+import importlib.resources as pkg_resources
 
 
-DATA_DIR = os.path.join(os.path.dirname(__file__), 'data')
+#DATA_DIR = os.path.join(os.path.dirname(__file__), 'data')
 
-EXTRACTOR_FILENAME = os.path.join(DATA_DIR, 'classifier')
-EXTRACTOR_DATA = os.path.join(DATA_DIR, 'train.data')
+EXTRACTOR_FILENAME = 'taloncb/signature/data/classifier'
+EXTRACTOR_DATA = 'taloncb/signature/data/train.data'
 
 
 def initialize():
